@@ -772,7 +772,8 @@ print.logregmodel <- function(x, nms, notnms, pstyle = 1, ...)
    scores <- scores[(lscores - ntr + 1):lscores]
    for(j in 1:ntr) {
       if(x$trees[[j]]$trees[1,5]!=0){
-         if(is.na(scores[j])==FALSE){
+         tmp <- (scores[j] >= 0)
+         if(is.na(tmp)==FALSE){
          if(scores[j] >= 0)
             cat(" +", signif(scores[j], 3), " * ", sep = "")
          else cat(" ", signif(scores[j], 3), " * ", sep = "")
